from typing import *


def read_json(
    path_or_buf: Union[_io.TextIOWrapper, _io.StringIO, str],
    orient: Literal["values", "columns", "index", "records", "split"] = ...,
    lines: bool = ...,
):
    """
    usage.dask: 13
    """
    ...
